@@ -1,5 +1,3 @@
-import pandas as pd
-import numpy as np
 
 
 def dataRead(path_, index_):
@@ -27,7 +25,6 @@ def SplusSminusVector(weighted_, Aplus, Aminus):
     Sminus = [sum(list(map(lambda x,y : (x-y)**2, weighted_.iloc[i],Aminus)))**0.5 for i in range(0, len(weighted_))]
     return Splus, Sminus
 
-
 ##############################################################################
 ######### İdeal çözüme olan göreli yakınlık değerlerinin hesaplanması ########
 ##############################################################################
